#!/usr/bin/ruby

#
# refltr 0.1
#

$:.unshift(File.join(File.dirname(__FILE__), 'lib'))

require 'refltr/facebook'
require 'refltr/test'

#
# Create a file and write data to it
#

def write_file(filename, data)
	File.open(filename, File::CREAT|File::TRUNC|File::WRONLY, 0644) { |file|
		file.binmode
		file.write(data)
	}
end

#
# Delete a file
#

def delete_file(file)
	begin
		File.delete(file)
	rescue
	end
end

#
# Get the test name form the command line
#

if ARGV.length != 1
  puts "Usage: ./refltr.rb <test>"
  exit(1)
end

tests = []

if ARGV[0] == 'all'
	tests = Refltr::Test.list
else
	tests.push(ARGV[0])
end

tests.each { |name|
	puts "Running test #{name}" if tests.length > 1

	data = Refltr::Test.new(name).data

	Dir.mkdir("results/#{name}") if !File.exist?("results/#{name}")

	write_file("results/#{name}/input.html", data)

	# Delete output and error files before sending the request

	delete_file("results/#{name}/output.html")
	delete_file("results/#{name}/error.html")

	begin
		output = Refltr::Facebook.new.test_fbml(data)

		write_file("results/#{name}/output.html", output.result)

		if output.errors
			puts "Facebook returned error messages, saved in error.html"
			write_file("results/#{name}/error.html", output.errors)
		end

	rescue Refltr::Facebook::Error => e
		puts "Facebook error, output body written to error.html"
		write_file("results/#{name}/error.html", e.body)
	end

	sleep 1
}
